@@ -3,6 +3,7 @@ import json
 from functools import wraps
 from six.moves.urllib.request import urlopen
 
+import rsa
 import jwt
 from flask import request, jsonify, _request_ctx_stack
 
@@ -115,9 +116,15 @@ class AuthHelper:
         :raise: AuthError
         """
         try:
+            if rsa_key.get('alg') != 'RS256' and rsa_key.get('use') != 'sig':
+                raise AuthError({
+                    'code': 'token_invalid',
+                    'description': 'Can only decode RSA auth tokens at this time.'
+                }, 401)
+            rsa_key_pem = rsa.PublicKey(rsa_key['n'], rsa_key['e']).save_pkcs1()
             payload = jwt.decode(
                 token,
-                rsa_key,
+                rsa_key_pem,
                 algorithms=self.__algorithms,
                 audience=self.__audience,
                 issuer=f'https://{self.__auth0_domain}/'
