@@ -136,6 +136,7 @@ def test_handle_rsa_decode(mocker):
     - return the decoded token object
     """
     mock_jwt = mocker.patch('busie_flask.auth.jwt')
+    mock_rsa = mocker.patch('busie_flask.auth.rsa')
     class MockExpiredSignature(Exception):
         """Mock Expired Signature Error"""
     class MockInvalidAudience(Exception):
@@ -143,7 +144,7 @@ def test_handle_rsa_decode(mocker):
     class MockInvalidIssuer(Exception):
         """Mock Invalid Issuer Errror"""
     mock_token = 'sometoken'
-    mock_key = {'some': 'key'}
+    mock_key = {'alg': 'RS256', 'use': 'sig', 'n': 'thenvalue', 'e': 'theevalue'}
     mock_algorithms = ['algos']
     mock_domain = 'foo.com'
     mock_audience = 'someaudience'
@@ -153,9 +154,11 @@ def test_handle_rsa_decode(mocker):
     auth._AuthHelper__audience = mock_audience
 
     decoded = auth.handle_rsa_decode(mock_key, mock_token)
+    mock_rsa.PublicKey.assert_called_once_with(mock_key['n'], mock_key['e'])
+    mock_rsa.PublicKey.return_value.save_pkcs1.assert_called_once()
     mock_jwt.decode.assert_called_once_with(
         mock_token,
-        mock_key,
+        mock_rsa.PublicKey.return_value.save_pkcs1.return_value,
         algorithms=mock_algorithms,
         audience=mock_audience,
         issuer=f'https://{mock_domain}/'
@@ -165,11 +168,15 @@ def test_handle_rsa_decode(mocker):
     mock_jwt.ExpiredSignatureError = MockExpiredSignature
     mock_jwt.InvalidAudienceError = MockInvalidAudience
     mock_jwt.InvalidIssuerError = MockInvalidIssuer
-    exceptions = [mock_jwt.ExpiredSignatureError, mock_jwt.InvalidAudienceError, mock_jwt.InvalidIssuerError]
+    exceptions = [mock_jwt.ExpiredSignatureError, mock_jwt.InvalidAudienceError, mock_jwt.InvalidIssuerError, AuthError]
     for e in exceptions:
         mock_jwt.decode.side_effect = e
+        args_list = [
+            mock_key if e is not AuthError else {},
+            'token'
+        ]
         with pytest.raises(AuthError):
-            auth.handle_rsa_decode({}, 'token')
+            auth.handle_rsa_decode(*args_list)
 
 def test_requires_auth(mocker):
     """
